package skiplist.gui;

import java.util.Optional;

import javafx.fxml.FXML;
import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.scene.text.Font;
import skiplist.model.SkipList;

public class Controller {
	@FXML
	TextField data;
	
	@FXML
	TextArea display;
	
	SkipList<String> model = new SkipList<>();
	
	@FXML
	public void initialize() {
		display.setFont(new Font("Courier", 12));
	}
	
	@FXML
	void add() {
		get().ifPresent(item -> refresh(() -> model.add(item)));
	}
	
	@FXML
	void check() {
		get().ifPresent(item -> {
			Alert alert = new Alert(AlertType.INFORMATION);
			Optional<String> found = model.lookup(item);
			alert.setContentText(found.isPresent() ? "Found" : "Not found");
			alert.show();
			refresh();
		});
	}
	
	@FXML
	void remove() {
		get().ifPresent(item -> refresh(() -> model.remove(item)));
	}
	
	@FXML
	void clear() {
		model = new SkipList<>();
		refresh();
	}
	
	Optional<String> get() {
		return data.getText().length() > 0 ? Optional.of(data.getText()) : Optional.empty();
	}
	
	void refresh() {
		refresh(() -> {});
	}
	
	void refresh(Runnable run) {
		run.run();
		display.setText(model.toString());
		data.setText("");
	}
}
